MockClient class
Constructors
- MockClient(MockClientHandler _handler)
- Creates a MockClient with a handler that receives GetxRequests and sends GetxResponses.
Properties
Methods
-
close(
) → void -
Closes the GetxRequest and cleans up any resources associated with it.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send<
T> (GetxRequest< T> request) → Future<GetxResponse< T> > -
Sends an HTTP GetxRequest.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited