ErrorStatus<T, S> class

Inheritance
Available extensions

Constructors

ErrorStatus([S? error])
const

Properties

data → T?

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
error → S?
final
error → dynamic

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
errorMessage String

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
hashCode int
The hash code for this object.
no setterinherited
isCustom bool

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
isEmpty bool

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
isError bool

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
isLoading bool

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
isSuccess bool

Available on GetStatus<T>, provided by the StatusDataExt extension

no setter
props List
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited