GetMaterialApp class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- GetMaterialApp
Constructors
-
GetMaterialApp({Key? key, GlobalKey<
ScaffoldMessengerState> ? scaffoldMessengerKey, Widget? home, String? initialRoute, TransitionBuilder? builder, TextDirection? textDirection, String title = '', GenerateAppTitle? onGenerateTitle, Color? color, ThemeData? theme, ThemeData? darkTheme, ThemeMode themeMode = ThemeMode.system, Locale? locale, Iterable<LocalizationsDelegate> ? localizationsDelegates, LocaleListResolutionCallback? localeListResolutionCallback, LocaleResolutionCallback? localeResolutionCallback, Iterable<Locale> supportedLocales = const <Locale>[Locale('en', 'US')], bool debugShowMaterialGrid = false, bool showPerformanceOverlay = false, bool checkerboardRasterCacheImages = false, bool checkerboardOffscreenLayers = false, bool showSemanticsDebugger = false, bool debugShowCheckedModeBanner = true, Map<LogicalKeySet, Intent> ? shortcuts, ScrollBehavior? scrollBehavior, CustomTransition? customTransition, VoidCallback? onInit, VoidCallback? onReady, VoidCallback? onDispose, ValueChanged<Routing?> ? routingCallback, Transition? defaultTransition, List<GetPage> ? getPages, bool? opaqueRoute, bool? enableLog = kDebugMode, LogWriterCallback? logWriterCallback, bool? popGesture, Duration? transitionDuration, bool? defaultGlobalState, SmartManagement smartManagement = SmartManagement.full, List<Binding> binds = const [], GetPage? unknownRoute, ThemeData? highContrastTheme, ThemeData? highContrastDarkTheme, Map<Type, Action< ? actions})Intent> > -
const
Properties
-
actions
→ Map<
Type, Action< ?Intent> > -
final
-
binds
→ List<
Binding> -
final
- builder → TransitionBuilder?
-
final
- checkerboardOffscreenLayers → bool
-
final
- checkerboardRasterCacheImages → bool
-
final
- color → Color?
-
final
- customTransition → CustomTransition?
-
final
- darkTheme → ThemeData?
-
final
- debugShowCheckedModeBanner → bool
-
final
- debugShowMaterialGrid → bool
-
final
- defaultGlobalState → bool?
-
final
- defaultTransition → Transition?
-
final
- enableLog → bool?
-
final
-
getPages
→ List<
GetPage> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highContrastDarkTheme → ThemeData?
-
final
- highContrastTheme → ThemeData?
-
final
- home → Widget?
-
final
- initialRoute → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- locale → Locale?
-
final
- localeListResolutionCallback → LocaleListResolutionCallback?
-
final
- localeResolutionCallback → LocaleResolutionCallback?
-
final
-
localizationsDelegates
→ Iterable<
LocalizationsDelegate> ? -
final
- logWriterCallback → LogWriterCallback?
-
final
-
final
-
final
- onDispose → VoidCallback?
-
final
- onGenerateTitle → GenerateAppTitle?
-
final
- onInit → VoidCallback?
-
final
- onReady → VoidCallback?
-
final
- opaqueRoute → bool?
-
final
- popGesture → bool?
-
final
-
routingCallback
→ ValueChanged<
Routing?> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scaffoldMessengerKey
→ GlobalKey<
ScaffoldMessengerState> ? -
final
- scrollBehavior → ScrollBehavior?
-
final
-
shortcuts
→ Map<
LogicalKeySet, Intent> ? -
final
- showPerformanceOverlay → bool
-
final
- showSemanticsDebugger → bool
-
final
- smartManagement → SmartManagement
-
final
-
supportedLocales
→ Iterable<
Locale> -
final
- textDirection → TextDirection?
-
final
- theme → ThemeData?
-
final
- themeMode → ThemeMode
-
final
- title → String
-
final
- transitionDuration → Duration?
-
final
- unknownRoute → GetPage?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited