GetMiddleware class abstract

Constructors

GetMiddleware({int priority = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
priority int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBindingsStart<R>(List<R>? bindings) List<R>?
onPageBuildStart(GetPageBuilder? page) GetPageBuilder?
onPageBuilt(Widget page) Widget
onPageCalled(GetPage? page) GetPage?
onPageDispose() → void
redirect(String? route) RouteSettings?
redirectDelegate(RouteSettings route) FutureOr<RouteSettings?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited