GetWidgetCacheImpl<S extends GetLifeCycleMixin> class

Inheritance

Constructors

GetWidgetCacheImpl()

Properties

context BuildContext?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
info InstanceInfo?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget GetWidget<S>?
no setterinherited

Methods

build(BuildContext context) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose() → void
override
onInit() → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited