ErrorStatus<T, S> class
- Inheritance
- Available extensions
Constructors
- ErrorStatus([S? error])
-
const
Properties
- data → T?
-
Available on GetStatus<
T> , provided by the StatusDataExt extensionno setter - error → S?
-
final
- error → dynamic
-
Available on GetStatus<
T> , provided by the StatusDataExt extensionno setter - errorMessage → String
-
Available on GetStatus<
T> , provided by the StatusDataExt extensionno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- isCustom → bool
-
Available on GetStatus<
T> , provided by the StatusDataExt extensionno setter - isEmpty → bool
-
Available on GetStatus<
T> , provided by the StatusDataExt extensionno setter - isError → bool
-
Available on GetStatus<
T> , provided by the StatusDataExt extensionno setter - isLoading → bool
-
Available on GetStatus<
T> , provided by the StatusDataExt extensionno setter - isSuccess → bool
-
Available on GetStatus<
T> , provided by the StatusDataExt extensionno setter - props → List
-
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited